betty.documentation module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.documentation module

Provide the Documentation API.

class betty.documentation.DocumentationServer

  Bases: `Server`

  Serve the documentation site.

  Parameters:

    - cache_directory_path (`pathlib.Path`)

    - localizer (`betty.locale.Localizer`)

  __init__(cache_directory_path: pathlib.Path, *, localizer: betty.locale.Localizer)
    Parameters:

      - cache_directory_path (`pathlib.Path`)

      - localizer (`betty.locale.Localizer`)

  classmethod label() → betty.locale.Str

    Get the server’s human-readable label.

    Return type:

      `betty.locale.Str`

  property public_url: str

    The server’s public URL.

  async start() → None

    Start the server.

    Return type:

      `None`

  async stop() → None

    Stop the server.

    Return type:

      `None`